import * as React from 'react';
import { DefaultRouterOptions, DefaultNavigatorOptions, NavigationState, ParamListBase, RouterFactory, PartialState, PrivateValueStore, NavigationAction } from './types';
/**
 * Hook for building navigators.
 *
 * @param createRouter Factory method which returns router object.
 * @param options Options object containing `children` and additional options for the router.
 * @returns An object containing `state`, `navigation`, `descriptors` objects.
 */
export default function useNavigationBuilder<State extends NavigationState, RouterOptions extends DefaultRouterOptions, ScreenOptions extends object, EventMap extends {
    [key: string]: any;
}>(createRouter: RouterFactory<State, any, RouterOptions>, options: DefaultNavigatorOptions<ScreenOptions> & RouterOptions): {
    state: State;
    navigation: {
        dispatch(action: NavigationAction | ((state: NavigationState) => NavigationAction)): void;
        navigate<RouteName extends React.ReactText>(...args: ParamListBase[RouteName] extends any ? [RouteName] | [RouteName, ParamListBase[RouteName]] : [RouteName, ParamListBase[RouteName]]): void;
        navigate<RouteName_1 extends React.ReactText>(route: {
            key: string;
            params?: ParamListBase[RouteName_1] | undefined;
        } | {
            name: RouteName_1;
            key?: string | undefined;
            params: ParamListBase[RouteName_1];
        }): void;
        replace<RouteName_2 extends React.ReactText>(...args: ParamListBase[RouteName_2] extends undefined ? [RouteName_2] | [RouteName_2, ParamListBase[RouteName_2]] : [RouteName_2, ParamListBase[RouteName_2]]): void;
        reset(state: NavigationState | PartialState<NavigationState>): void;
        resetRoot(state: NavigationState | PartialState<NavigationState>): void;
        goBack(): void;
        isFocused(): boolean;
        canGoBack(): boolean;
    } & PrivateValueStore<ParamListBase, React.ReactText, {}> & import("./types").EventEmitter<EventMap> & {
        setParams<RouteName_3 extends React.ReactText>(params: ParamListBase[RouteName_3]): void;
    } & {
        dispatch(action: NavigationAction | ((state: any) => NavigationAction)): void;
        navigate<RouteName_4 extends React.ReactText>(...args: ParamListBase[RouteName_4] extends any ? [RouteName_4] | [RouteName_4, ParamListBase[RouteName_4]] : [RouteName_4, ParamListBase[RouteName_4]]): void;
        navigate<RouteName_5 extends React.ReactText>(route: {
            key: string;
            params?: ParamListBase[RouteName_5] | undefined;
        } | {
            name: RouteName_5;
            key?: string | undefined;
            params: ParamListBase[RouteName_5];
        }): void;
        replace<RouteName_6 extends React.ReactText>(...args: ParamListBase[RouteName_6] extends undefined ? [RouteName_6] | [RouteName_6, ParamListBase[RouteName_6]] : [RouteName_6, ParamListBase[RouteName_6]]): void;
        reset(state: any): void;
        resetRoot(state: NavigationState | PartialState<NavigationState>): void;
        goBack(): void;
        isFocused(): boolean;
        canGoBack(): boolean;
    } & {
        setParams(params: object | undefined): void;
        setOptions(options: Partial<any>): void;
        isFirstRouteInParent(): boolean;
        dangerouslyGetParent<T = import("./types").NavigationProp<ParamListBase, string, NavigationState, {}, {}> | undefined>(): T;
        dangerouslyGetState(): any;
    } & import("./types").EventConsumer<any> & PrivateValueStore<ParamListBase, string, any>;
    descriptors: {
        [key: string]: import("./types").Descriptor<ParamListBase, string, State, ScreenOptions, {}>;
    };
};
