import * as React from 'react';
import { NavigationEventEmitter } from './useEventEmitter';
import { NavigationProp, NavigationAction, NavigationState, ParamListBase, Router, PrivateValueStore } from './types';
declare type Options<State extends NavigationState, Action extends NavigationAction> = {
    onAction: (action: NavigationAction, visitedNavigators?: Set<string>) => boolean;
    getState: () => State;
    emitter: NavigationEventEmitter;
    router: Router<State, Action>;
};
/**
 * Navigation object with helper methods to be used by a navigator.
 * This object includes methods for common actions as well as methods the parent screen's navigation object.
 */
export default function useNavigationHelpers<State extends NavigationState, Action extends NavigationAction, EventMap extends {
    [key: string]: any;
}>({ onAction, getState, emitter, router }: Options<State, Action>): {
    dispatch(action: NavigationAction | ((state: NavigationState) => NavigationAction)): void;
    navigate<RouteName extends React.ReactText>(...args: ParamListBase[RouteName] extends any ? [RouteName] | [RouteName, ParamListBase[RouteName]] : [RouteName, ParamListBase[RouteName]]): void;
    navigate<RouteName_1 extends React.ReactText>(route: {
        key: string;
        params?: ParamListBase[RouteName_1] | undefined;
    } | {
        name: RouteName_1;
        key?: string | undefined;
        params: ParamListBase[RouteName_1];
    }): void;
    replace<RouteName_2 extends React.ReactText>(...args: ParamListBase[RouteName_2] extends undefined ? [RouteName_2] | [RouteName_2, ParamListBase[RouteName_2]] : [RouteName_2, ParamListBase[RouteName_2]]): void;
    reset(state: NavigationState | import("./types").PartialState<NavigationState>): void;
    resetRoot(state: NavigationState | import("./types").PartialState<NavigationState>): void;
    goBack(): void;
    isFocused(): boolean;
    canGoBack(): boolean;
} & PrivateValueStore<ParamListBase, React.ReactText, {}> & import("./types").EventEmitter<EventMap> & {
    setParams<RouteName_3 extends React.ReactText>(params: ParamListBase[RouteName_3]): void;
} & {
    dispatch(action: NavigationAction | ((state: any) => NavigationAction)): void;
    navigate<RouteName_4 extends React.ReactText>(...args: ParamListBase[RouteName_4] extends any ? [RouteName_4] | [RouteName_4, ParamListBase[RouteName_4]] : [RouteName_4, ParamListBase[RouteName_4]]): void;
    navigate<RouteName_5 extends React.ReactText>(route: {
        key: string;
        params?: ParamListBase[RouteName_5] | undefined;
    } | {
        name: RouteName_5;
        key?: string | undefined;
        params: ParamListBase[RouteName_5];
    }): void;
    replace<RouteName_6 extends React.ReactText>(...args: ParamListBase[RouteName_6] extends undefined ? [RouteName_6] | [RouteName_6, ParamListBase[RouteName_6]] : [RouteName_6, ParamListBase[RouteName_6]]): void;
    reset(state: any): void;
    resetRoot(state: NavigationState | import("./types").PartialState<NavigationState>): void;
    goBack(): void;
    isFocused(): boolean;
    canGoBack(): boolean;
} & {
    setParams(params: object | undefined): void;
    setOptions(options: Partial<any>): void;
    isFirstRouteInParent(): boolean;
    dangerouslyGetParent<T = NavigationProp<ParamListBase, string, NavigationState, {}, {}> | undefined>(): T;
    dangerouslyGetState(): any;
} & import("./types").EventConsumer<any> & PrivateValueStore<ParamListBase, string, any>;
export {};
